@@ -581,6 +581,36 @@ class OpenEVSE:
             _LOGGER.debug("Non-semver firmware version detected.")
         return False
 
+    # Self production HTTP Posting
+
+    async def self_production(
+        self, grid: int | None = None, solar: int | None = None, invert: bool = True
+    ) -> None:
+        """Send pushed sensor data to self-prodcution."""
+        if not self._version_check("4.0.0"):
+            _LOGGER.debug("Feature not supported for older firmware.")
+            raise UnsupportedFeature
+
+        # Invert the sensor -import/+export
+        if invert and grid is not None:
+            grid = grid * -1
+
+        url = f"{self.url}status"
+        data = {}
+
+        # Prefer grid sensor data
+        if grid is not None:
+            data = {"grid_ie": grid}
+        elif solar is not None:
+            data = {"solar": solar}
+
+        if not data:
+            _LOGGER.info("No sensor data to send to device.")
+        else:
+            _LOGGER.debug("Posting self-production: %s", data)
+            response = await self.process_request(url=url, method="post", data=data)
+            _LOGGER.debug("Self-production response: %s", response)
+
     @property
     def hostname(self) -> str:
         """Return charger hostname."""
